@@ -17,6 +17,8 @@
 #include <QStandardPaths>
 #include <QVBoxLayout>
 
+#include <QLocale>
+
 #include <QStyleOption>
 #include <QStylePainter>
 
@@ -30,7 +32,7 @@
 #include "ctcron.h"
 #include "cthost.h"
 #include "cttask.h"
-#include "logging.h"
+#include "kcm_cron_debug.h"
 
 #include "crontabWidget.h"
 
@@ -52,14 +54,14 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
     mCtTask = _ctTask;
     mCrontabWidget = _crontabWidget;
 
-    QWidget *main = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(main);
+    auto main = new QWidget(this);
+    auto mainLayout = new QVBoxLayout(main);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
 
-    QVBoxLayout *dialogLayout = new QVBoxLayout();
+    auto dialogLayout = new QVBoxLayout();
     dialogLayout->addWidget(main);
     dialogLayout->addWidget(buttonBox);
     setLayout(dialogLayout);
@@ -71,14 +73,14 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
 
     mainLayout->addWidget(mTitleWidget);
 
-    QGridLayout *commandConfigurationLayout = new QGridLayout();
+    auto commandConfigurationLayout = new QGridLayout();
     mainLayout->addLayout(commandConfigurationLayout);
 
     // command
-    QLabel *labCommand = new QLabel(i18n("&Command:"), main);
+    auto labCommand = new QLabel(i18n("&Command:"), main);
     commandConfigurationLayout->addWidget(labCommand, 0, 0);
 
-    QHBoxLayout *commandLayout = new QHBoxLayout();
+    auto commandLayout = new QHBoxLayout();
     mCommandIcon = new QLabel(main);
     mMissingCommandPixmap = QIcon::fromTheme(QStringLiteral("image-missing")).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize, nullptr, this));
     commandLayout->addWidget(mCommandIcon);
@@ -96,7 +98,7 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
     commandConfigurationLayout->addLayout(commandLayout, 0, 1);
 
     // User Combo
-    QLabel *userLabel = new QLabel(i18n("&Run as:"), main);
+    auto userLabel = new QLabel(i18n("&Run as:"), main);
     commandConfigurationLayout->addWidget(userLabel, 1, 0);
 
     mUserCombo = new QComboBox(main);
@@ -104,6 +106,7 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
     userLabel->setBuddy(mUserCombo);
     commandConfigurationLayout->addWidget(mUserCombo, 1, 1);
 
+    // When in multiuser (system) mode, a user column is required.
     if (mCrontabWidget->tasksWidget()->needUserColumn()) {
         KCronHelper::initUserCombo(mUserCombo, mCrontabWidget, mCtTask->userLogin);
     } else {
@@ -112,7 +115,7 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
     }
 
     // comment
-    QLabel *labComment = new QLabel(i18n("Co&mment:"), main);
+    auto labComment = new QLabel(i18n("Co&mment:"), main);
     commandConfigurationLayout->addWidget(labComment, 2, 0, Qt::AlignTop);
 
     mLeComment = KCronHelper::createCommentEdit(main);
@@ -121,7 +124,7 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
 
     mLeComment->setText(mCtTask->comment);
 
-    QHBoxLayout *checkboxesLayout = new QHBoxLayout();
+    auto checkboxesLayout = new QHBoxLayout();
     mainLayout->addLayout(checkboxesLayout);
 
     // enabled
@@ -140,10 +143,10 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
     mCbEveryDay->setChecked(everyDay);
     checkboxesLayout->addWidget(mCbEveryDay);
 
-    QHBoxLayout *schedulingLayout = new QHBoxLayout();
+    auto schedulingLayout = new QHBoxLayout();
     mainLayout->addLayout(schedulingLayout);
 
-    QVBoxLayout *monthLayout = new QVBoxLayout();
+    auto monthLayout = new QVBoxLayout();
     schedulingLayout->addLayout(monthLayout);
 
     // months
@@ -151,7 +154,7 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
     monthLayout->addWidget(mBgMonth);
     monthLayout->addStretch(1);
 
-    QVBoxLayout *v1 = new QVBoxLayout();
+    auto v1 = new QVBoxLayout();
     schedulingLayout->addLayout(v1);
 
     // days of the month
@@ -164,7 +167,7 @@ TaskEditorDialog::TaskEditorDialog(CTTask *_ctTask, const QString &_caption, Cro
 
     v1->addStretch(1);
 
-    QVBoxLayout *v2 = new QVBoxLayout();
+    auto v2 = new QVBoxLayout();
     schedulingLayout->addLayout(v2);
 
     mHoursGroup = createHoursGroup(main);
@@ -239,13 +242,13 @@ bool TaskEditorDialog::isEveryDay()
 
 QGroupBox *TaskEditorDialog::createDaysOfMonthGroup(QWidget *main)
 {
-    QGroupBox *daysOfMonthGroup = new QGroupBox(i18n("Days of Month"), main);
-    QGridLayout *daysOfMonthLayout = new QGridLayout(daysOfMonthGroup);
+    auto daysOfMonthGroup = new QGroupBox(i18n("Days of Month"), main);
+    auto daysOfMonthLayout = new QGridLayout(daysOfMonthGroup);
 
     int dm = CTDayOfMonth::MINIMUM;
     for (int row = 0; row < 5; ++row) {
         for (int column = 0; column < 7; ++column) {
-            NumberPushButton *day = new NumberPushButton(true, daysOfMonthGroup);
+            auto day = new NumberPushButton(true, daysOfMonthGroup);
             day->setText(QString::number(dm));
             day->setCheckable(true);
             day->setChecked(mCtTask->dayOfMonth.isEnabled(dm));
@@ -276,8 +279,8 @@ QGroupBox *TaskEditorDialog::createDaysOfMonthGroup(QWidget *main)
 
 QGroupBox *TaskEditorDialog::createMonthsGroup(QWidget *main)
 {
-    QGroupBox *monthsGroup = new QGroupBox(i18n("Months"), main);
-    QGridLayout *monthsLayout = new QGridLayout(monthsGroup);
+    auto monthsGroup = new QGroupBox(i18n("Months"), main);
+    auto monthsLayout = new QGridLayout(monthsGroup);
 
     int column = 0;
     int row = 0;
@@ -312,8 +315,8 @@ QGroupBox *TaskEditorDialog::createMonthsGroup(QWidget *main)
 
 QGroupBox *TaskEditorDialog::createDaysOfWeekGroup(QWidget *main)
 {
-    QGroupBox *daysOfWeekGroup = new QGroupBox(i18n("Days of Week"), main);
-    QGridLayout *daysOfWeekLayout = new QGridLayout(daysOfWeekGroup);
+    auto daysOfWeekGroup = new QGroupBox(i18n("Days of Week"), main);
+    auto daysOfWeekLayout = new QGridLayout(daysOfWeekGroup);
 
     int column = 0;
     int row = 0;
@@ -359,12 +362,12 @@ bool TaskEditorDialog::canReduceMinutesGroup()
 
 void TaskEditorDialog::emptyMinutesGroup()
 {
-    logDebug() << "Empty minutes layout";
+    qCDebug(KCM_CRON_LOG) << "Empty minutes layout";
 
     for (int minuteIndex = 0; minuteIndex <= minuteTotal; ++minuteIndex) {
         mMinutesLayout->removeWidget(mMinuteButtons[minuteIndex]);
         mMinuteButtons[minuteIndex]->hide();
-        logDebug() << "Layout count" << mMinutesLayout->count();
+        qCDebug(KCM_CRON_LOG) << "Layout count" << mMinutesLayout->count();
     }
 
     mMinutesLayout->removeItem(mMinutesPreselectionLayout);
@@ -384,7 +387,7 @@ void TaskEditorDialog::increaseMinutesGroup()
     */
     emptyMinutesGroup();
 
-    logDebug() << "Show all minutes";
+    qCDebug(KCM_CRON_LOG) << "Show all minutes";
 
     int minuteIndex = 0;
     for (int row = 0; row < (minuteTotal + 1) / minutePerColumn; ++row) {
@@ -402,7 +405,7 @@ void TaskEditorDialog::increaseMinutesGroup()
 
 void TaskEditorDialog::reduceMinutesGroup()
 {
-    logDebug() << "Reducing view";
+    qCDebug(KCM_CRON_LOG) << "Reducing view";
 
     emptyMinutesGroup();
 
@@ -420,7 +423,7 @@ void TaskEditorDialog::reduceMinutesGroup()
                 nextRow = 1;
             }
         } else {
-            logDebug() << "Reducing id" << minuteIndex;
+            qCDebug(KCM_CRON_LOG) << "Reducing id" << minuteIndex;
             mCtTask->minute.setEnabled(minuteIndex, false);
             mMinuteButtons[minuteIndex]->setChecked(false);
         }
@@ -433,7 +436,7 @@ void TaskEditorDialog::reduceMinutesGroup()
 
 NumberPushButton *TaskEditorDialog::createMinuteButton(int minuteIndex)
 {
-    NumberPushButton *minuteButton = new NumberPushButton(true, mMinutesGroup);
+    auto minuteButton = new NumberPushButton(true, mMinutesGroup);
     minuteButton->setText(QString::number(minuteIndex));
     minuteButton->setCheckable(true);
     minuteButton->setChecked(mCtTask->minute.isEnabled(minuteIndex));
@@ -446,7 +449,7 @@ NumberPushButton *TaskEditorDialog::createMinuteButton(int minuteIndex)
 
 void TaskEditorDialog::createMinutesGroup(QWidget *main)
 {
-    logDebug() << "Creating minutes group";
+    qCDebug(KCM_CRON_LOG) << "Creating minutes group";
 
     mMinutesGroup = new QGroupBox(i18n("Minutes"), main);
 
@@ -458,7 +461,7 @@ void TaskEditorDialog::createMinutesGroup(QWidget *main)
 
     mMinutesPreselectionLayout = new QHBoxLayout();
 
-    QLabel *minutesPreselectionLabel = new QLabel(i18n("Preselection:"));
+    auto minutesPreselectionLabel = new QLabel(i18n("Preselection:"));
     mMinutesPreselectionLayout->addWidget(minutesPreselectionLabel);
 
     mMinutesPreselection = new QComboBox(this);
@@ -487,12 +490,12 @@ void TaskEditorDialog::createMinutesGroup(QWidget *main)
         reduceMinutesGroup();
     }
 
-    logDebug() << "Minutes group created";
+    qCDebug(KCM_CRON_LOG) << "Minutes group created";
 }
 
 NumberPushButton *TaskEditorDialog::createHourButton(QGroupBox *hoursGroup, int hour)
 {
-    NumberPushButton *hourButton = new NumberPushButton(true, hoursGroup);
+    auto hourButton = new NumberPushButton(true, hoursGroup);
     hourButton->setText(QString::number(hour));
     hourButton->setCheckable(true);
     hourButton->setChecked(mCtTask->hour.isEnabled(hour));
@@ -505,38 +508,49 @@ NumberPushButton *TaskEditorDialog::createHourButton(QGroupBox *hoursGroup, int
 
 QGroupBox *TaskEditorDialog::createHoursGroup(QWidget *main)
 {
-    logDebug() << "Creating hours group";
-    QGroupBox *hoursGroup = new QGroupBox(i18n("Hours"), main);
+    // Hide the AM/PM labels if the locale is set to 24h format.
+    // 'A' or 'a' means am/pm is shown (and then 'h' uses 12-hour format)
+    // but 'H' forces a 24-hour format anyway, even with am/pm shown.
+    const QString str = QLocale().timeFormat();
+    static bool use12Clock = str.contains(QLatin1Char('a'), Qt::CaseInsensitive) && !str.contains(QLatin1Char('H'));
 
-    QGridLayout *hoursLayout = new QGridLayout(hoursGroup); // 5 x 7
+    qCDebug(KCM_CRON_LOG) << "Creating hours group";
+    auto hoursGroup = new QGroupBox(i18n("Hours"), main);
 
-    mMorningLabel = new QLabel(i18n("AM:"), this);
-    mMorningLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-    mMorningLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
-    hoursLayout->addWidget(mMorningLabel, 0, 0, Qt::AlignLeft | Qt::AlignVCenter);
+    auto hoursLayout = new QGridLayout(hoursGroup); // 5 x 6 (24h) // 5 x 7 (12h)
+
+    if (use12Clock) {
+        mMorningLabel = new QLabel(i18n("AM:"), this);
+        mMorningLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+        mMorningLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
+        hoursLayout->addWidget(mMorningLabel, 0, 0, Qt::AlignLeft | Qt::AlignVCenter);
+    }
 
     int hourCount = 0;
     for (int column = 0; column <= 3; ++column) {
         for (int hour = 0; hour <= 5; ++hour) {
             NumberPushButton *hourButton = createHourButton(hoursGroup, hourCount);
             mHourButtons[hourCount] = hourButton;
-            hoursLayout->addWidget(hourButton, column, hour + 1);
+            // When using the 12h format, the hour buttons need to be inserted 1 column over to leave room for the AM/PM labels.
+            hoursLayout->addWidget(hourButton, column, hour + (use12Clock ? 1 : 0));
             hourCount++;
         }
     }
 
-    mAfternoonLabel = new QLabel(i18n("PM:"), this);
-    mAfternoonLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-    mAfternoonLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
-    hoursLayout->addWidget(mAfternoonLabel, 2, 0, Qt::AlignLeft | Qt::AlignVCenter);
+    if (use12Clock) {
+        mAfternoonLabel = new QLabel(i18n("PM:"), this);
+        mAfternoonLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+        mAfternoonLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
+        hoursLayout->addWidget(mAfternoonLabel, 2, 0, Qt::AlignLeft | Qt::AlignVCenter);
+    }
 
     mAllHours = new SetOrClearAllButton(this, SetOrClearAllButton::SET_ALL);
-    hoursLayout->addWidget(mAllHours, 4, 0, 1, 7);
+    hoursLayout->addWidget(mAllHours, 4, 0, 1, use12Clock ? 7 : 6);
 
     connect(mAllHours, &SetOrClearAllButton::clicked, this, &TaskEditorDialog::slotAllHours);
     connect(mAllHours, &SetOrClearAllButton::clicked, this, &TaskEditorDialog::slotWizard);
 
-    logDebug() << "Create hours group";
+    qCDebug(KCM_CRON_LOG) << "Create hours group";
     return hoursGroup;
 }
 
@@ -648,7 +662,7 @@ void TaskEditorDialog::slotOK()
 
     if ((weekDaysSelected == 0) && (monthDaysSelected > 0)) {
         for (int dw = 1; dw <= 7; dw++) {
-            mDayOfWeekButtons[dw]->setChecked(1);
+            mDayOfWeekButtons[dw]->setChecked(true);
         }
     }
 
@@ -720,7 +734,7 @@ bool TaskEditorDialog::checkCommand()
     QString path = pathCommand.at(0);
     QString binaryCommand = pathCommand.at(1);
 
-    logDebug() << "Looking for " << binaryCommand << "in" << path;
+    qCDebug(KCM_CRON_LOG) << "Looking for " << binaryCommand << "in" << path;
 
     bool found = false;
     bool exec = false;
@@ -936,13 +950,10 @@ void TaskEditorDialog::slotAllDaysOfWeek()
 
 void TaskEditorDialog::slotDayOfWeekChanged()
 {
-    bool allChecked = true;
     bool allCleared = true;
     for (int dw = 1; dw <= 7; dw++) {
         if (mDayOfWeekButtons[dw]->isChecked()) {
             allCleared = false;
-        } else {
-            allChecked = false;
         }
     }
     if (allCleared) {
@@ -968,13 +979,10 @@ void TaskEditorDialog::slotAllHours()
 
 void TaskEditorDialog::slotHourChanged()
 {
-    bool allChecked = true;
     bool allCleared = true;
     for (int ho = 0; ho <= 23; ho++) {
         if (mHourButtons[ho]->isChecked()) {
             allCleared = false;
-        } else {
-            allChecked = false;
         }
     }
 
@@ -989,7 +997,7 @@ void TaskEditorDialog::slotMinutesPreselection(int index)
 {
     QVariant itemData = mMinutesPreselection->itemData(index);
     int step = itemData.toInt();
-    logDebug() << "Selected step " << step;
+    qCDebug(KCM_CRON_LOG) << "Selected step " << step;
 
     if (step == -1) {
         // Unselect everything
